@@ -5,7 +5,7 @@ from types import SimpleNamespace
 from monkeydict import MonkeyDict
 
 
-VERSION = '0.9.9.11'
+VERSION = '0.9.9.14'
 
 # Test Suite Configuration
 class Config(MonkeyDict):
@@ -51,15 +51,16 @@ class Config(MonkeyDict):
 
     # Make configuration paths absolute
     def make_paths_absolute(self):
-        self.general.result_path = os.path.abspath(self.general.result_path) if self.general.result_path else None
+        self.general.result_path = os.path.abspath(self.general.result_path) if hasattr(self.general, "result_path") else None
 
-        self.build.base = os.path.abspath(self.build.base) if self.build.base else None
-        self.build.destination = os.path.abspath(self.build.destination) if self.build.destination else None
+        self.build.base = os.path.abspath(self.build.base) if hasattr(self.build, "base") else None
+        self.build.destination = os.path.abspath(self.build.destination) if hasattr(self.build, "destination") else None
+        self.build.resources = os.path.abspath(self.build.resources) if hasattr(self.build, "resources") else None
 
-        self.build.subject_src = os.path.abspath(self.build.subject_src) if self.build.subject_src else None
-        self.build.subject_bin = os.path.abspath(self.build.subject_bin) if self.build.subject_bin else None
-        self.build.framework_src = os.path.abspath(self.build.framework_src) if self.build.framework_src else None
-        self.build.framework_bin = os.path.abspath(self.build.framework_bin) if self.build.framework_bin else None
+        self.build.subject_src = os.path.abspath(self.build.subject_src) if hasattr(self.build, "subject_src") else None
+        self.build.subject_bin = os.path.abspath(self.build.subject_bin) if hasattr(self.build, "subject_bin") else None
+        self.build.framework_src = os.path.abspath(self.build.framework_src) if hasattr(self.build, "framework_src") else None
+        self.build.framework_bin = os.path.abspath(self.build.framework_bin) if hasattr(self.build, "framework_bin") else None
 
 
     ######################################################
