@@ -46,6 +46,7 @@ def build_project(source_root, build_root, build_cfg):
 
     # If there is a not a specified build directory, fall back to the source directory instead.
     if not build_root:
+        logging.info("No build root; assuming the build root is the source root (" + source_root + ")")
         build_root = source_root
 
     # If the build exists, remove old project folder, recreate it, and switch to it.
@@ -71,7 +72,7 @@ def build_project(source_root, build_root, build_cfg):
                 for entry in source_cmd:
                     template.template = entry
                     prep_cmd.append(template.substitute(**replacements))
-                subprocess.check_output(prep_cmd, stderr=subprocess.STDOUT)
+                subprocess.check_output(prep_cmd, stderr=subprocess.STDOUT, text=True)
 
         if hasattr(build_cfg, 'compile_cmd') and build_cfg.compile_cmd:
             # Apply substitutions from the build configuration to the compile command
@@ -81,7 +82,7 @@ def build_project(source_root, build_root, build_cfg):
                 for entry in build_cfg.compile_cmd:
                     template.template = entry
                     compile_cmd.append(template.substitute(**replacements))
-                subprocess.check_output(compile_cmd, stderr=subprocess.STDOUT)
+                subprocess.check_output(compile_cmd, stderr=subprocess.STDOUT, text=True)
 
         if hasattr(build_cfg, 'post_cmd') and build_cfg.post_cmd:
             # Apply substitutions from the build configuration to the prep command(s)
@@ -91,7 +92,7 @@ def build_project(source_root, build_root, build_cfg):
                 for entry in source_cmd:
                     template.template = entry
                     post_cmd.append(template.substitute(**replacements))
-                subprocess.check_output(post_cmd, stderr=subprocess.STDOUT)
+                subprocess.check_output(post_cmd, stderr=subprocess.STDOUT, text=True)
 
     except subprocess.CalledProcessError as error:
         result_error = error
